"""
Language Country (or more exact region) combos are sort of based on the ISO 639,
but the combination itself is not maintained by a standard organisation. This
means I just make it up here and thus am burdened with maintenance of it.
"""

SPECIFIERS = [
    # Code, Description
    ['sm', 'Simplified'],
    ['tr', 'Traditional'],
    ['cy', 'Cyrillic'],
    ['lt', 'Latin']]


LANGUAGE_TLD = [
    # Language Code, Country Code, Specifier, Default
    ['af',  'ZA',   '', False],
    ['ar',  'AE',   '', False],
    ['ar',  'BH',   '', False],
    ['ar',  'DZ',   '', False],
    ['ar',  'EG',   '', True],
    ['ar',  'IQ',   '', False],
    ['ar',  'JO',   '', False],
    ['ar',  'KW',   '', False],
    ['ar',  'LB',   '', False],
    ['ar',  'LY',   '', False],
    ['ar',  'MA',   '', False],
    ['ar',  'OM',   '', False],
    ['ar',  'QA',   '', False],
    ['ar',  'SA',   '', False],
    ['ar',  'SY',   '', False],
    ['ar',  'TN',   '', False],
    ['ar',  'YE',   '', False],
    ['az',  'AZ', 'cy', False],
    ['az',  'AZ', 'lt', False],
    ['be',  'BY',   '', False],
    ['bg',  'BG',   '', False],
    ['ca',  'ES',   '', False],
    ['cs',  'CZ',   '', False],
    ['da',  'DK',   '', False],
    ['de',  'AT',   '', False],
    ['de',  'CH',   '', False],
    ['de',  'DE',   '', True],
    ['de',  'LI',   '', False],
    ['de',  'LU',   '', False],
    ['dv',  'MV',   '', False],
    ['el',  'GR',   '', False],
    ['en',  'AU',   '', False],
    ['en',  'BZ',   '', False],
    ['en',  'CA',   '', False],
    ['en',  'CB',   '', False],
    ['en',  'GB',   '', True],
    ['en',  'IE',   '', False],
    ['en',  'JM',   '', False],
    ['en',  'NZ',   '', False],
    ['en',  'PH',   '', False],
    ['en',  'TT',   '', False],
    ['en',  'US',   '', False],
    ['en',  'ZA',   '', False],
    ['en',  'ZW',   '', False],
    ['es',  'AR',   '', False],
    ['es',  'BO',   '', False],
    ['es',  'CL',   '', False],
    ['es',  'CO',   '', False],
    ['es',  'CR',   '', False],
    ['es',  'DO',   '', False],
    ['es',  'EC',   '', False],
    ['es',  'ES',   '', True],
    ['es',  'GT',   '', False],
    ['es',  'HN',   '', False],
    ['es',  'MX',   '', False],
    ['es',  'NI',   '', False],
    ['es',  'PA',   '', False],
    ['es',  'PE',   '', False],
    ['es',  'PR',   '', False],
    ['es',  'PY',   '', False],
    ['es',  'SV',   '', False],
    ['es',  'UY',   '', False],
    ['es',  'VE',   '', False],
    ['et',  'EE',   '', False],
    ['eu',  'ES',   '', False],
    ['fa',  'IR',   '', False],
    ['fi',  'FI',   '', False],
    ['fo',  'FO',   '', False],
    ['fr',  'BE',   '', False],
    ['fr',  'CA',   '', False],
    ['fr',  'CH',   '', False],
    ['fr',  'FR',   '', True],
    ['fr',  'LU',   '', False],
    ['fr',  'MC',   '', False],
    ['gl',  'ES',   '', False],
    ['gu',  'IN',   '', False],
    ['he',  'IL',   '', False],
    ['hi',  'IN',   '', False],
    ['hr',  'HR',   '', False],
    ['hu',  'HU',   '', False],
    ['hy',  'AM',   '', False],
    ['id',  'ID',   '', False],
    ['is',  'IS',   '', False],
    ['it',  'CH',   '', False],
    ['it',  'IT',   '', True],
    ['ja',  'JP',   '', False],
    ['ka',  'GE',   '', False],
    ['kk',  'KZ',   '', False],
    ['kn',  'IN',   '', False],
    ['ko',  'KR',   '', False],
    ['kok', 'IN',   '', False],
    ['ky',  'KZ',   '', False],
    ['lt',  'LT',   '', False],
    ['lv',  'LV',   '', False],
    ['mk',  'MK',   '', False],
    ['mn',  'MN',   '', False],
    ['mr',  'IN',   '', False],
    ['ms',  'BN',   '', False],
    ['ms',  'MY',   '', True],
    ['nb',  'NO',   '', False],
    ['nl',  'BE',   '', False],
    ['nl',  'NL',   '', True],
    ['nn',  'NO',   '', False],
    ['pa',  'IN',   '', False],
    ['pl',  'PL',   '', False],
    ['pt',  'BR',   '', False],
    ['pt',  'PT',   '', True],
    ['ro',  'RO',   '', False],
    ['ru',  'RU',   '', False],
    ['sa',  'IN',   '', False],
    ['sk',  'SK',   '', False],
    ['sl',  'SI',   '', False],
    ['sq',  'AL',   '', False],
    ['sr',  'RS', 'cy', False],
    ['sr',  'RS', 'lt', False],
    ['sv',  'FI',   '', False],
    ['sv',  'SE',   '', True],
    ['sw',  'KE',   '', False],
    ['ta',  'IN',   '', False],
    ['te',  'IN',   '', False],
    ['th',  'TH',   '', False],
    ['tr',  'TR',   '', False],
    ['tt',  'RU',   '', False],
    ['uk',  'UA',   '', False],
    ['ur',  'PK',   '', False],
    ['uz',  'UZ', 'cy', False],
    ['uz',  'UZ', 'lt', False],
    ['vi',  'VN',   '', False],
    ['zh',  'CN',   '', True],
    ['zh',  'CN', 'sm', False],
    ['zh',  'CN', 'tr', False],
    ['zh',  'HK',   '', False],
    ['zh',  'MO',   '', False],
    ['zh',  'SG',   '', False],
    ['zh',  'TW',   '', False]]


def get():
    "Just return the data as a dictionary."
    return {'specifiers':SPECIFIERS,
            'language_tld':LANGUAGE_TLD}
